@@ -2,11 +2,11 @@
 
 import gettext
 
-VERSION = "3.1.1"
+VERSION = "3.2.0"
 PACKAGE = "gedit-latex"
-PACKAGE_STRING = "gedit-latex 3.1.1"
+PACKAGE_STRING = "gedit-latex 3.2.0"
 GETTEXT_PACKAGE = "gedit-latex"
-GL_LOCALEDIR = "/usr/share/locale"
+GL_LOCALEDIR = "/home/jaliste/install/share/locale"
 
 try:
     gettext.bindtextdomain(GETTEXT_PACKAGE, GL_LOCALEDIR)
